const app = getApp()

import Notify from '@vant/weapp/notify/notify';

import {
  repairListRq,
  getQueryStatusName,
  deviceTypeListRq,
  selectAddressListRq
} from "../../../../api/repair/repair.js"

Page({

  /**
   * 页面的初始数据
   */
  data: {
    search: {
      type: '0',
      address: '0',
      isShowAll: '1',
      opType: [{
        text: '全部类型',
        value: '0'
      }],
      opAddress: [{
        text: '全部地点',
        value: '0'
      }],
      opIsShowAll: [{
        text: '全部范围',
        value: '1'
      }, {
        text: '本人报修',
        value: '0'
      }],
    },

    // tabBar param
    tabBarParam: {
      selected: 0,
      color: "#515151",
      selectedColor: "#217CFF",
      backgroundColor: "#ffffff",
    },
    // tabBar menu
    tabBarList: [{
        "pagePath": "/pages/index/index",
        "iconPath": "/images/tabbar/home.png",
        "selectedIconPath": "/images/tabbar/home-select.png",
        "text": "首页"
      },
      {
        "pagePath": "/pages/reportRepair/report/report",
        "iconPath": "/images/tabbar/center.png",
        "selectedIconPath": "/images/tabbar/center.png",
        "text": "报修",
        "bulge": true,
      },
      {
        "pagePath": "/pages/my/my",
        "iconPath": "/images/tabbar/my.png",
        "selectedIconPath": "/images/tabbar/my-select.png",
        "text": "我的"
      },
    ],
    IMG_NAME: app.IMG_NAME,
    userData: null,
    dataChange: false,
    tabTitle: '全部',
    // 全部
    allOrder: {
      pageNum: 1,
      pageSize: 10,
      type: 'all',
      dataList: [],
      isDataAll: false,
    },
    // 处理中
    processOrder: {
      pageNum: 1,
      pageSize: 10,
      type: 'process',
      dataList: [],
      isDataAll: false,
    },
    // 待评价
    evalingOrder: {
      pageNum: 1,
      pageSize: 10,
      type: 'evaling',
      dataList: [],
      isDataAll: false,
    },
    // 已评价
    evaledOrder: {
      pageNum: 1,
      pageSize: 10,
      type: 'evaled',
      dataList: [],
      isDataAll: false,
    },
    //无效申请 
    invalidOrder: {
      pageNum: 1,
      pageSize: 10,
      type: 'invalid',
      dataList: [],
      isDataAll: false,
    },
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {
    let _this = this;
    _this.setData({
      userData: wx.getStorageSync('user'),
    })
    console.log(_this.data.userData)
    // 获取数据
    let userId = _this.data.userData.id
    _this.queryDeviceType()
    _this.queryAddress()
  },
  // 查询设备类型
  queryDeviceType() {
    let _this = this
    deviceTypeListRq().then(res => {
      console.log('deviceTypeListRq', res);
      let _opType = _this.data.search.opType
      let list = res.rows.map(item => {
        return {
          value: item.id,
          text: item.name
        }
      })
      _opType = _opType.concat(list)
      _this.setData({
        ['search.opType']: _opType
      })
    })
  },
  // 查询地点
  queryAddress() {
    let _this = this
    selectAddressListRq().then(res => {
      let _opAddress = _this.data.search.opAddress
      let list = res.rows.map(item => {
        return {
          value: item.id,
          text: item.name
        }
      })
      _opAddress = _opAddress.concat(list)
      _this.setData({
        ['search.opAddress']: _opAddress
      })
    })
  },
  // 类型搜索变更方法
  typeChange(e) {
    // console.log('typeChange', e)
    let _this = this
    let _value = e.detail
    _this.setData({
      ['search.type']: _value
    })
    // 直接重新查询
    _this.getAllData()
  },
  // 地点搜索变更方法
  addressChange(e) {
    // console.log('addressChange', e)
    let _this = this
    let _value = e.detail
    _this.setData({
      ['search.address']: _value
    })
     // 直接重新查询
     _this.getAllData()
  },
  // 查询范围变更方法
  isShowAllChange(e) {
    let _this = this
    let _value = e.detail
    _this.setData({
      ['search.isShowAll']: _value
    })
     // 直接重新查询
     _this.getAllData()
  },

  // 切换tabbar
  switchTab(e) {
    const data = e.currentTarget.dataset
    console.log('switchTab', data)
    const url = data.path
    if (url == '/pages/reportRepair/report/report') {
      wx.navigateTo({
        url
      })
    } else {
      wx.switchTab({
        url
      })
    }
  },

  // tab 点击切换
  tabClickSwitch(event) {
    console.log('tabClickSwitch', event);
    let _this = this;
    _this.setData({
      tabTitle: event.detail.title
    })
  },

  // 获取数据
  getDataList(transferTabTitle) {
    console.log(transferTabTitle)
    // 获取参数
    let _this = this;
    let tabTitle = _this.data.tabTitle
    if (transferTabTitle) {
      tabTitle = transferTabTitle
    }
    let pageNum = null
    let pageSize = null
    let type = null
    let isDataAll = null

    //
    let allOrder = _this.data.allOrder
    let processOrder = _this.data.processOrder
    let evalingOrder = _this.data.evalingOrder
    let evaledOrder = _this.data.evaledOrder
    let invalidOrder = _this.data.invalidOrder

    let searchType = _this.data.search.type
    let searchAddress = _this.data.search.address
    let searchIsShowAll = _this.data.search.isShowAll
    // 默认为空
    searchType = searchType == '0' ? '' : searchType
    searchAddress = searchAddress == '0' ? '' : searchAddress

    if (tabTitle == '全部') {
      pageNum = allOrder.pageNum
      pageSize = allOrder.pageSize
      type = allOrder.type
      isDataAll = allOrder.isDataAll

    } else if (tabTitle == '处理中') {
      pageNum = processOrder.pageNum
      pageSize = processOrder.pageSize
      type = processOrder.type
      isDataAll = processOrder.isDataAll

    } else if (tabTitle == '待评价') {
      pageNum = evalingOrder.pageNum
      pageSize = evalingOrder.pageSize
      type = evalingOrder.type
      isDataAll = evalingOrder.isDataAll

    } else if (tabTitle == '已评价') {
      pageNum = evaledOrder.pageNum
      pageSize = evaledOrder.pageSize
      type = evaledOrder.type
      isDataAll = evaledOrder.isDataAll

    } else if (tabTitle == '无效单') {
      pageNum = invalidOrder.pageNum
      pageSize = invalidOrder.pageSize
      type = invalidOrder.type
      isDataAll = invalidOrder.isDataAll

    } else {
      wx.showToast({
        title: `tab 切换错误(${tabTitle})`,
        icon: 'none',
      });
      return;
    }

    // 判断数据是否已全部加载
    if (isDataAll) {
      return;
    }
    let _role = _this.data.userData.dataType
    if (_role == 5 || _role == 3) {
      // 维修人员、派单员，非管理人员，仅可查看自己的报修记录
      _role = 1
    }
    if (_role == 9 || _role == 7) {
      // 管理人员可以切换自己上报的或所有的
      if (searchIsShowAll == 0) {
        // 为0，则只显示自己上报的
        _role = 1
      }
    }
    // 传递参数
    let param = {
      pageNum,
      pageSize,
      menu: _role, // 角色
      type,
      role: _role, // 角色
      repair: {
        typeId: searchType, // 类型筛选
        addressId: searchAddress, // 地点筛选
      }
    }
    // 查询数据        
    repairListRq(param).then(res => {
      // console.log('repairListRq', res);
      let dataList = res.rows
      let _isDataAll = false
      if (pageNum * pageSize >= res.total) {
        _isDataAll = true
      }
      //
      if (tabTitle == '全部') {
        allOrder.dataList = allOrder.dataList.concat(_this.formartData(dataList))
        allOrder.pageNum = allOrder.pageNum + 1
        allOrder.isDataAll = _isDataAll
        _this.setData({
          allOrder
        })

      } else if (tabTitle == '处理中') {
        processOrder.dataList = processOrder.dataList.concat(_this.formartData(dataList))
        processOrder.pageNum = processOrder.pageNum + 1
        processOrder.isDataAll = _isDataAll
        _this.setData({
          processOrder
        })

      } else if (tabTitle == '待评价') {
        evalingOrder.dataList = evalingOrder.dataList.concat(_this.formartData(dataList))
        evalingOrder.pageNum = evalingOrder.pageNum + 1
        evalingOrder.isDataAll = _isDataAll
        _this.setData({
          evalingOrder
        })

      } else if (tabTitle == '已评价') {
        evaledOrder.dataList = evaledOrder.dataList.concat(_this.formartData(dataList))
        evaledOrder.pageNum = evaledOrder.pageNum + 1
        evaledOrder.isDataAll = _isDataAll
        _this.setData({
          evaledOrder
        })

      } else if (tabTitle == '无效单') {
        invalidOrder.dataList = invalidOrder.dataList.concat(_this.formartData(dataList))
        invalidOrder.pageNum = invalidOrder.pageNum + 1
        invalidOrder.isDataAll = _isDataAll
        _this.setData({
          invalidOrder
        })

      }

    })
  },

  // 格式化数据
  formartData(dataList) {
    // 格式化数据
    return dataList.map(item => {
      let ext1 = item.ext1
      if (ext1) {
        item.visibleImg = ext1
      } else {
        item.visibleImg = '/profile/static/repair/index/noneImg.png'
      }
      item.statusName = getQueryStatusName(item.status)
      return item;
    })
  },

  jumpDetail(e) {
    console.log('jumpDetail', e);
    let obj = e.currentTarget.dataset.obj
    wx.navigateTo({
      url: `/pages/reportRepair/assign/detail/detail?id=${obj.id}`,
    })
  },

  jumpEvaluate(e) {
    let obj = e.currentTarget.dataset.obj
    console.log('jumpEvaluate', obj);
    wx.navigateTo({
      url: `/pages/reportRepair/assign/evaluate/evaluate?id=${obj.id}&back=1`,
    })
  },
  // 获取所有数据方法
  getAllData() {
    let _this = this;
    _this.setData({
      // 全部
      allOrder: {
        pageNum: 1,
        pageSize: 10,
        type: 'all',
        dataList: [],
        isDataAll: false,
      },
      // 处理中
      processOrder: {
        pageNum: 1,
        pageSize: 10,
        type: 'process',
        dataList: [],
        isDataAll: false,
      },
      // 待评价
      evalingOrder: {
        pageNum: 1,
        pageSize: 10,
        type: 'evaling',
        dataList: [],
        isDataAll: false,
      },
      // 已评价
      evaledOrder: {
        pageNum: 1,
        pageSize: 10,
        type: 'evaled',
        dataList: [],
        isDataAll: false,
      },
      //无效申请 
      invalidOrder: {
        pageNum: 1,
        pageSize: 10,
        type: 'invalid',
        dataList: [],
        isDataAll: false,
      },
    })
    //
    _this.getDataList('全部')
    _this.getDataList('处理中')
    _this.getDataList('待评价')
    _this.getDataList('已评价')
    _this.getDataList('无效单')
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {
    this.getAllData()
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {
    console.log('onPullDownRefresh', '页面相关事件处理函数--监听用户下拉动作');

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {
    console.log('onReachBottom', '页面上拉触底事件的处理函数');
    let _this = this;
    // 获取数据
    let tabTitle = _this.data.tabTitle
    _this.getDataList(tabTitle)
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage(e) {
    console.log('onShareAppMessage', e);
    let _this = this;
    let obj = e.target.dataset.obj
    let title = `${obj.address + '/' + obj.floor}（${obj.room}）${obj.typeName}`
    //
    let param = {
      title,
      path: `/pages/reportRepair/assign/detail/detail?id=${obj.id}`,
      imageUrl: app.IMG_NAME + obj.visibleImg,
    }
    console.log('onShareAppMessage', param);
    return param;
  }
})